#[repr(C)]
pub struct rcl_node_options_t { pub domain_id: usize, pub allocator: rcl_allocator_t, pub use_global_arguments: bool, pub arguments: rcl_arguments_t, pub enable_rosout: bool, }
Structure which encapsulates the options for creating a rcl_node_t.

Fields

domain_id: usize

If set, then this value overrides the ROS_DOMAIN_ID environment variable.

allocator: rcl_allocator_t

Custom allocator used for internal allocations.

use_global_arguments: bool

If false then only use arguments in this struct, otherwise use global arguments also.

arguments: rcl_arguments_t

Command line arguments that apply only to this node.

enable_rosout: bool

Flag to enable rosout for this node