Struct rcl_sys::rcl::node_options::rcl_node_options_t
source · [−]#[repr(C)]pub struct rcl_node_options_t {
pub domain_id: usize,
pub allocator: rcl_allocator_t,
pub use_global_arguments: bool,
pub arguments: rcl_arguments_t,
pub enable_rosout: bool,
}Expand description
Structure which encapsulates the options for creating a rcl_node_t.
Fields
domain_id: usizeIf set, then this value overrides the ROS_DOMAIN_ID environment variable.
allocator: rcl_allocator_tCustom allocator used for internal allocations.
use_global_arguments: boolIf false then only use arguments in this struct, otherwise use global arguments also.
arguments: rcl_arguments_tCommand line arguments that apply only to this node.
enable_rosout: boolFlag to enable rosout for this node